.. -*- coding: utf-8 -*-
.. :Project:   python-rapidjson -- Sphinx documentation
.. :Author:    Lele Gaifax <lele@metapensiero.it>
.. :License:   MIT License
.. :Copyright: © 2016, 2017, 2020 Lele Gaifax
..

==================
 python-rapidjson
==================

----------------------------------
Python 3 wrapper around RapidJSON_
----------------------------------

This module implements a Python 3 wrapper around RapidJSON_, which is an extremely fast
C++ JSON_ serialization library.

Contents:

.. toctree::
   :maxdepth: 2

   quickstart
   benchmarks
   api

.. _RapidJSON: http://rapidjson.org/
.. _JSON: https://www.json.org/


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
